@@ -6,6 +6,7 @@ SERVICE_NAME = 'ecs'
 CONTAINER_DEFAULT_NAME = 'gunicorn'
 COMMAND_NAME = 'run_task'
 
+
 class AWSECSHandler:
     """AWS ECS service handler."""
 
@@ -18,19 +19,25 @@ class AWSECSHandler:
             region_name=settings.AWS_DEFAULT_REGION,
         )
         self.container_default_name = CONTAINER_DEFAULT_NAME
-        self.task_definition = settings.AWS_TASK_DEFINITION
         self.command_name = COMMAND_NAME
 
     def run_task(
-            self, launch_type=settings.AWS_CLUSTER_LAUNCH,
-            cluster=settings.AWS_CLUSTER, command=None,
-            task_definition=settings.AWS_TASK_DEFINITION):
+            self,
+            command=None,
+            launch_type=settings.AWS_CLUSTER_LAUNCH,
+            cluster=settings.AWS_CLUSTER,
+            task_definition=settings.AWS_TASK_DEFINITION,
+            logging=settings.AWS_LOGGING,
+            logConfiguration=settings.AWS_LOGGING_CONFIGURATION):
         """Run Task definition on ECS Cluster."""
         run_kwargs = {
             'cluster': cluster,
             'launchType': launch_type,
-            'taskDefinition': self.task_definition,
+            'taskDefinition': task_definition,
+            'logging': logging,
+            'logConfiguration': logConfiguration
         }
+
         if command:
             command = command.split() if isinstance(command, str) else command
             run_kwargs['overrides'] = {
@@ -41,4 +48,4 @@ class AWSECSHandler:
                     }
                 ]
             }
-        return self.client.run_task(**run_kwargs)
\ No newline at end of file
+        return self.client.run_task(**run_kwargs)
